==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/escape/KnownSizeDetector.h <==
// public class org.dellroad.jc.cgen.escape.KnownSizeDetector

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 459c3dfdc696805f org_dellroad_jc_cgen_escape_KnownSizeDetector
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch

// header file dependencies
// @dep_header soot_jimple_AbstractJimpleValueSwitch

#include "soot/jimple/AbstractJimpleValueSwitch.h"

#ifndef _JC_org_dellroad_jc_cgen_escape_KnownSizeDetector_H_
#define _JC_org_dellroad_jc_cgen_escape_KnownSizeDetector_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_ArrayType$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_NewArrayExpr$object;
struct _jc_soot_jimple_NewExpr$object;
struct _jc_soot_jimple_NewMultiArrayExpr$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$sub_refs	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$sub_nonrefs	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$refs	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$nonrefs	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object;

typedef struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$fields_struct	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$fields_struct;
typedef const struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vmethods	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtable	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtype	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$fields_struct {
	jint	OBJECT__5fHEADER__5fSIZE;
	jint	REFERENCE__5fSIZE;
};
extern _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$fields_struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *);

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method$caseNewArrayExpr$a253d21e8d16d4b1(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method$caseNewExpr$a19e03ca0d8a8f14(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method$caseNewMultiArrayExpr$517ba3e177c22c7f(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method$defaultCase$6711cf3c099fadd1(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_java_lang_Object$object *);
extern void _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method$doArray$17ea9cc81a9f7c98(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_object *, struct _jc_soot_ArrayType$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method_info$caseNewArrayExpr$a253d21e8d16d4b1;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method_info$caseNewExpr$a19e03ca0d8a8f14;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method_info$caseNewMultiArrayExpr$517ba3e177c22c7f;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method_info$defaultCase$6711cf3c099fadd1;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method_info$doArray$17ea9cc81a9f7c98;

// Static methods
extern jint _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method$size$954eb32e0e809267(_jc_env *, struct _jc_soot_Type$object *);

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vmethods {
	void	(*caseNewArrayExpr$a253d21e8d16d4b1)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_object *);
	void	(*caseNewExpr$a19e03ca0d8a8f14)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_object *);
	void	(*caseNewMultiArrayExpr$517ba3e177c22c7f)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_object *);
	void	(*defaultCase$6711cf3c099fadd1)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_java_lang_Object$object *);
	void	(*doArray$17ea9cc81a9f7c98)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_object *, struct _jc_soot_ArrayType$object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vmethods	org_dellroad_jc_cgen_escape_KnownSizeDetector;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$refs {
    _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$sub_refs	org_dellroad_jc_cgen_escape_KnownSizeDetector;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$sub_nonrefs	org_dellroad_jc_cgen_escape_KnownSizeDetector;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object {
	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtype _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_escape_KnownSizeDetector, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_escape_KnownSizeDetector_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/escape/KnownSizeDetector.h <==
// public class org.dellroad.jc.cgen.escape.KnownSizeDetector

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 459c3dfdc696805f org_dellroad_jc_cgen_escape_KnownSizeDetector
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch

// header file dependencies
// @dep_header soot_jimple_AbstractJimpleValueSwitch

#include "soot/jimple/AbstractJimpleValueSwitch.h"

#ifndef _JC_org_dellroad_jc_cgen_escape_KnownSizeDetector_H_
#define _JC_org_dellroad_jc_cgen_escape_KnownSizeDetector_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_ArrayType$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_NewArrayExpr$object;
struct _jc_soot_jimple_NewExpr$object;
struct _jc_soot_jimple_NewMultiArrayExpr$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$sub_refs	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$sub_nonrefs	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$refs	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$nonrefs	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object;

typedef struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$fields_struct	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$fields_struct;
typedef const struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vmethods	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtable	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtype	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$fields_struct {
	jint	OBJECT__5fHEADER__5fSIZE;
	jint	REFERENCE__5fSIZE;
};
extern _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$fields_struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method$caseNewArrayExpr$a253d21e8d16d4b1(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method$caseNewExpr$a19e03ca0d8a8f14(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method$caseNewMultiArrayExpr$517ba3e177c22c7f(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method$defaultCase$6711cf3c099fadd1(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method$doArray$17ea9cc81a9f7c98(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_object *, struct _jc_soot_ArrayType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method_info$caseNewArrayExpr$a253d21e8d16d4b1;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method_info$caseNewExpr$a19e03ca0d8a8f14;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method_info$caseNewMultiArrayExpr$517ba3e177c22c7f;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method_info$defaultCase$6711cf3c099fadd1;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method_info$doArray$17ea9cc81a9f7c98;

// Static methods
extern jint _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$method$size$954eb32e0e809267(_jc_env *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vmethods {
	void	(*caseNewArrayExpr$a253d21e8d16d4b1)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseNewExpr$a19e03ca0d8a8f14)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseNewMultiArrayExpr$517ba3e177c22c7f)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*defaultCase$6711cf3c099fadd1)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*doArray$17ea9cc81a9f7c98)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object *, struct _jc_object *, struct _jc_soot_ArrayType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vmethods	org_dellroad_jc_cgen_escape_KnownSizeDetector;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$refs {
    _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$sub_refs	org_dellroad_jc_cgen_escape_KnownSizeDetector;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$sub_nonrefs	org_dellroad_jc_cgen_escape_KnownSizeDetector;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$object {
	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$vtype _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_escape_KnownSizeDetector, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_escape_KnownSizeDetector$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_escape_KnownSizeDetector_H_ */
